@@ -33,6 +33,12 @@ class RKAdmin(RKClient):
                  sort_order: str = '',
                  filters: Optional[Dict] = None) -> Tuple[List[PEM], str, bool]:
         """
+        :param page_index:
+        :param page_size:
+        :param sort_field:
+        :param sort_order:
+        :param filters: contains dict of key:value pairs, which all have to be contained in PEM fields to be returned.
+                ID, Emitter and Predecessor should be hex values of UUID (without dashes).
         :return: first element: list of pems (as json string) or error message
                  The artifacts lists in PEM will contain only artifact ID
                  second element: True for success, False for error
@@ -57,6 +63,9 @@ class RKAdmin(RKClient):
                        sort_field: str = '',
                        sort_order: str = '',
                        filters: Optional[Dict] = None) -> Tuple[int, str, bool]:
+        """
+        Returns amount of PEMs which match the filters. See `get_pems` for more info.
+        """
 
         def _get_pems() -> Tuple[int, str, bool]:
             query_params: Dict[str, Any] = _parse_sorting_filtering_params(page_index, page_size,
@@ -91,7 +100,7 @@ class RKAdmin(RKClient):
                       sort_order: str = '',
                       filters: Optional[Dict] = None ) -> Tuple[List[Artifact], str, bool]:
         """
-        :param source: from which db to return artifacts, 'sqldb' or 'graphdb'
+        :param source: from which db to return artifacts, 'sqldb' or 'graphdb'. Warning: 'graphdb' doesn't return Artifacts with properties.
         :param page_index:
         :param page_size:
         :param sort_field:
