@@ -8,6 +8,7 @@ import urllib.request
 import urllib.response
 import urllib.parse
 from urllib.error import URLError, HTTPError
+from socket import timeout
 import ssl
 
 from rkclient.auth import RK_USER_AUTH_HEADER
@@ -211,6 +212,8 @@ class RKClient:
             return f"error: {e} {e.read().decode()}", False
         except URLError as e:
             return f"connection error: {e}", False
+        except timeout as e:
+            return f"socket timed out in {self.timeout_sec}s: {e}", False
         else:
             return resp.read().decode(), True
 
