@@ -43,6 +43,10 @@ class Artifact:
     def __repr__(self):
         return self.__str__()
 
+    def __eq__(self, other):
+        return self.ID == other.ID and \
+               self.Type == other.Type and \
+               self.Properties == other.Properties
 
 class PEM:
 
