@@ -30,7 +30,7 @@ class ArtifactSerialization:
     def from_dict(d: Dict) -> Artifact:
         art = Artifact(
             id=UUID(hex=d['ID']),
-            type=d['Type'],
+            artifact_type=d['Type'],
             properties=d['Properties'],
         )
         art.CreatedAt = d['CreatedAt']
